Actor class

An actor base class. An actor is an object containing only functions that will return a promise. These functions are derived from the IDL definition.

Implementers

Constructors

Actor(ActorMetadata metadata)

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ ActorMetadata
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

agentOf(Actor actor) → Agent?
Get the Agent class this Actor would call, or undefined if the Actor would use the default agent (global.ic.agent). @param actor The actor to get the agent of.
canisterIdOf(Actor actor) → Principal
createActor(Service interfaceFactory, ActorConfig configuration) → CanisterActor
createActorClass(Service interfaceFactory) → ActorConstructor
createAndInstallCanister(Service interfaceFactory, FieldOptions fields, CallConfig? config) → dynamic
createCanister(CallConfig? config) → Future<Principal>
install(FieldOptions fields, ActorConfig config) → void
interfaceOf(Actor actor) → Service?
Get the interface of an actor, in the form of an instance of a Service. @param actor The actor to get the interface of.

Constants

metadataSymbol → const String