CallConfig class

Implementers

Constructors

CallConfig({Agent? agent, PollStrategyFactory? pollingStrategyFactory, Principal? canisterId, Principal? effectiveCanisterId})
CallConfig.fromMap(Map<String, dynamic> map)
factory

Properties

agent ↔ Agent?
An agent to use in this call, otherwise the actor or call will try to discover the agent to use.
getter/setter pair
canisterId ↔ Principal?
The canister ID of this Actor.
getter/setter pair
effectiveCanisterId ↔ Principal?
The effective canister ID. This should almost always be ignored.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pollingStrategyFactory ↔ PollStrategyFactory?
A polling strategy factory that dictates how much and often we should poll the read_state endpoint to get the result of an update call.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited