FieldOptions class

Constructors

FieldOptions(BinaryBlob module, {String? mode, BinaryBlob? arg})
FieldOptions.fromMap(Map<String, dynamic> map)
factory

Properties

arg ↔ BinaryBlob?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mode ↔ String?
getter/setter pair
module ↔ BinaryBlob
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited