CallOptions class

Options when doing a {@link Agent.call} call.

Constructors

CallOptions()

Properties

arg ↔ BinaryBlob
A binary encoded argument. This is already encoded and will be sent as is.
getter/setter pair
effectiveCanisterId ↔ Principal?
An effective canister ID, used for routing. This should only be mentioned if it's different from the canister ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
methodName ↔ String
The method name to call.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited