QueryResponse class abstract

Inheritance
Implementers

Constructors

QueryResponse()

Properties

hashCode → int
The hash code for this object.
no setterinherited
reject_code ↔ int?
getter/setter pair
reject_message ↔ String?
getter/setter pair
reply ↔ Reply?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited