FetchResponse class

Constructors

FetchResponse(String body, bool ok, int statusCode, String statusText, Uint8List arrayBuffer)
FetchResponse.fromMap(Map<String, dynamic> map)
factory

Properties

arrayBuffer → Uint8List
final
body → String
final
hashCode → int
The hash code for this object.
no setterinherited
ok → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final
statusText → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited