Expiry class

Inheritance

Constructors

Expiry(int deltaInMSec)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → BigInt
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHash() → Nonce
toString() → String
A string representation of this object.
inherited
write(Encoder encoder) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited