agent/auth library

Classes

AnonymousIdentity
Identity
IdentityDescriptor
Create an IdentityDescriptor from a @dfinity/authentication Identity @param identity - identity describe in returned descriptor
KeyPair
A Key Pair, containing a secret and public key.
PublicKey
SignIdentity
An Identity that can sign blobs.

Properties

domainSeparator → Uint8List
final

Functions

createIdentityDescriptor(Identity identity) → IdentityDescriptor
isIdentityDescriptor(dynamic value) → bool
Type Guard for whether the unknown value is an IdentityDescriptor or not. @param value - value to type guard