SignIdentity class abstract

An Identity that can sign blobs.

Implemented types
Implementers

Constructors

SignIdentity()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPrincipal() → Principal
Get the principal represented by this identity. Normally should be a Principal.selfAuthenticating().
override
getPublicKey() → PublicKey
Returns the public key that would match this identity's signature.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(BinaryBlob blob) → Future<BinaryBlob>
Signs a blob of data, with this identity's private key.
toString() → String
A string representation of this object.
inherited
transformRequest(HttpAgentRequest request) → Future
Transform a request into a signed version of the request. This is done last after the transforms on the body of a request. The returned object can be anything, but must be serializable to CBOR. @param request - internet computer request to transform
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited