Cert class

Constructors

Cert({List? tree, Uint8List? signature, Delegation? delegation})
Cert.fromJson(Map json)
factory

Properties

delegation ↔ Delegation?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature ↔ Uint8List?
getter/setter pair
tree ↔ List?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited