Delegation class

Implemented types

Constructors

Delegation(Uint8List? subnet_id, BinaryBlob certificate)
Delegation.fromJson(Map<String, dynamic> json)
factory

Properties

certificate ↔ Uint8List
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnet_id → Uint8List?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited