PollingResponseRejectedException class

Implemented types

Constructors

PollingResponseRejectedException({required String requestId, required String status, required String rejectCode, required String rejectMessage})

Properties

hashCode → int
The hash code for this object.
no setterinherited
rejectCode → String
final
rejectMessage → String
final
requestId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited