BufferPipe<T> class

Constructors

BufferPipe(Iterable<T> list)

Properties

buffer → List<T>
no setter
bytesRead → int
no setter
bytesWrote → int
no setter
end → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
length → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(int length) → List<T>
toString() → String
A string representation of this object.
inherited
write(Iterable<T> data) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited