agent/utils/utils library

Classes

BufferPipe<T>

Functions

idlHash(String s) → num
idlLabelToId(String label) → num
lebDecode<T>(BufferPipe<T> pipe) → BigInt
Decode a leb encoded buffer into a bigint. The number will always be positive (does not support signed leb encoding). @param pipe A Buffer containing the leb encoded bits.
lebEncode(dynamic value) → Uint8List
Encode a positive number (or bigint) into a Buffer. The number will be floored to the nearest integer. @param value The number to encode.
readIntLE(BufferPipe pipe, int byteLength) → BigInt
readUIntLE(BufferPipe pipe, int byteLength) → BigInt
safeRead<T>(BufferPipe<T> pipe, int ref) → List<T>
slebDecode(BufferPipe pipe) → BigInt
Decode a leb encoded buffer into a bigint. The number is decoded with support for negative signed-leb encoding. @param pipe A Buffer containing the signed leb encoded bits.
slebEncode(Comparable value) → Uint8List
Encode a number (or bigint) into a Buffer, with support for negative numbers. The number will be floored to the nearest integer. @param value The number to encode.
writeIntLE(dynamic value, int byteLength) → Uint8List
writeUIntLE(dynamic value, int byteLength) → Uint8List