MessageBlock class

Constructors

MessageBlock(Uint8List message, int algoId)

Properties

algoId → int
final
hashCode → int
The hash code for this object.
no setterinherited
message → Uint8List
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
write(OutputStreamBase output) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited