SigningBlock class

Constructors

SigningBlock.create({required List<Uint8List> messages, required List<Uint8List> signatures, required List<PublicKey> publicKeys, int algoId = 0x0201})

Properties

algoId ↔ int
getter/setter pair
blocksCount ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messageBlocks ↔ List<MessageBlock>
getter/setter pair
messages → List<Uint8List>
final
publicKeyBlocks ↔ List<PublicKeyBlock>
getter/setter pair
publicKeys → List<PublicKey>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatureBlocks ↔ List<SignatureBlock>
getter/setter pair
signatures → List<Uint8List>
final

Methods

getSize() → int
messageBlocksSize() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publicKeyBlocksSize() → int
signatureBlocksSize() → int
toString() → String
A string representation of this object.
inherited
write(OutputStreamBase output) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited