AuthClient class

Constructors

AuthClient({required String scheme, required AuthFunction authFunction, Identity? identity, String path = "", SignIdentity? key, DelegationChain? chain, Uri? authUri})
AuthClient.fromMap(String scheme, AuthFunction authFunction, Map<String, dynamic> map, Uri? authUri)
factory

Properties

authFunction ↔ AuthFunction
getter/setter pair
authUri ↔ Uri?
getter/setter pair
chain ↔ DelegationChain?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identity ↔ Identity?
getter/setter pair
key ↔ SignIdentity?
getter/setter pair
path ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme ↔ String
getter/setter pair

Methods

getIdentity() → Identity?
handleFailure(String? errorMessage, void onError(String? error)?) → void
handleSuccess(AuthResponseSuccess message, void onSuccess()?) → void
isAuthenticated() → Future<bool>
login([AuthClientLoginOptions? options]) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toStorage() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromStorage(String str) → FromStorageResult