AuthClientLoginOptions class

Constructors

AuthClientLoginOptions()

Properties

canisterId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identityProvider ↔ Uri?
Identity provider. By default, use the identity service.
getter/setter pair
maxTimeToLive ↔ BigInt?
Experiation of the authentication
getter/setter pair
onError ↔ void Function(String? error)?
Callback in case authentication fails
getter/setter pair
onSuccess ↔ void Function()?
Callback once login has completed
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited