FromStorageResult class

Constructors

FromStorageResult({DelegationChain? delegationChain, SignIdentity? signIdentity, DelegationIdentity? delegationIdentity})

Properties

delegationChain ↔ DelegationChain?
getter/setter pair
delegationIdentity ↔ DelegationIdentity?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signIdentity ↔ SignIdentity?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited