CreateUrlOptions class

Options for {@link createAuthenticationRequestUrl}. All these options may be limited further by the identity provider, or an error can happen.

Constructors

CreateUrlOptions()

Properties

hashCode → int
The hash code for this object.
no setterinherited
identityProvider ↔ String?
The URL base to use for the identity provider. By default, this is "https://auth.ic0.app/authorize".
getter/setter pair
publicKey ↔ PublicKey
The public key to delegate to. This should be the public key of the session key.
getter/setter pair
redirectUri ↔ Uri?
The URI to redirect to, after authentication. By default, window.location.origin.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ List
The scope of the delegation. This must contain at least one key and a maximum of four. This is validated in {@link createAuthenticationRequestUrl} but also will be validated as part of the identity provider.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited