CType<T> class abstract

Represents an IDL type.

Implementers

Constructors

CType()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<D, R>(Visitor<D, R> v, D d) → R
buildTypeTable(TypeTable typeTable) → void
checkType(CType t) → CType
covariant(dynamic x) → bool
Assert that JavaScript's x is the proper type represented by this Type.
decodeValue(Pipe x, CType t) → T
display() → String
encodeType(TypeTable? typeTable) → Uint8List
Implement I in the IDL spec. Encode this type for the type table.
encodeValue(T x) → Uint8List
Encode the value. This needs to be public because it is used by encodeValue() from different types. @internal
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
valueToString(T x) → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited