EmptyClass<T> class

Inheritance

Constructors

EmptyClass()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pairinherited-setteroverride-getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<D, R>(Visitor<D, R> v, D d) → R
override
buildTypeTable(TypeTable typeTable) → void
inherited
checkType(CType t) → CType
inherited
covariant(dynamic x) → bool
Assert that JavaScript's x is the proper type represented by this Type.
override
decodeValue(Pipe x, CType t) → T
override
display() → String
inherited
encodeType(TypeTable? typeTable) → Uint8List
Implement I in the IDL spec. Encode this type for the type table.
override
encodeValue(T x) → Uint8List
Encode the value. This needs to be public because it is used by encodeValue() from different types. @internal
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
valueToString(T x) → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited