FuncClass class

Inheritance

Constructors

FuncClass(List<CType> argTypes, List<CType> retTypes, List<String> annotations)

Properties

annotations → List<String>
final
argTypes → List<CType>
final
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pairinherited-setteroverride-getter
retTypes → List<CType>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<D, R>(Visitor<D, R> v, D d) → R
override
buildTypeTable(TypeTable typeTable) → void
inherited
checkType(CType t) → ConstructType
inherited
covariant(dynamic x) → bool
Assert that JavaScript's x is the proper type represented by this Type.
override
decodeValue(Pipe x, CType t) → List
override
display() → String
override
encodeAnnotation(String ann) → Uint8List
encodeType(TypeTable? typeTable) → Uint8List
Implement I in the IDL spec. Encode this type for the type table.
inherited
encodeValue(List x) → Uint8List
Encode the value. This needs to be public because it is used by encodeValue() from different types. @internal
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
valueToString(List x) → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

argsToString(List<CType> types, List v) → dynamic