identity/der library

Properties

DER_COSE_OID → Uint8List
A DER encoded SEQUENCE(OID) for DER-encoded-COSE
final
ED25519_OID → Uint8List
A DER encoded SEQUENCE(OID) for the Ed25519 algorithm
final

Functions

bufEquals(ByteBuffer b1, ByteBuffer b2) → bool
decodeLenBytes(Uint8List buf, int offset) → int
encodeLen(Uint8List buf, int offset, int len) → int
encodeLenBytes(int len) → int
unwrapDER(ByteBuffer derEncoded, Uint8List oid) → Uint8List
Extracts a payload from the given derEncoded data, and checks that it was tagged with the given oid.
wrapDER(ByteBuffer payload, Uint8List oid) → Uint8List
Wraps the given payload in a DER encoding tagged with the given encoded oid like so: SEQUENCE(oid, BITSTRING(payload))