Ed25519KeyIdentity class

Inheritance

Constructors

Ed25519KeyIdentity(PublicKey publicKey, BinaryBlob _privateKey)

Properties

accountId → BinaryBlob
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAccountId() → BinaryBlob
getKeyPair() → KeyPair
Return a copy of the key pair.
getPrincipal() → Principal
Get the principal represented by this identity. Normally should be a Principal.selfAuthenticating().
inherited
getPublicKey() → Ed25519PublicKey
Return the public key.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(dynamic challenge) → Future<BinaryBlob>
Signs a blob of data, with this identity's private key. @param challenge - challenge to sign with this identity's secretKey, producing a signature
override
toJSON() → JsonnableEd25519KeyIdentity
Serialize this key to JSON.
toString() → String
A string representation of this object.
inherited
transformRequest(HttpAgentRequest request) → Future
Transform a request into a signed version of the request. This is done last after the transforms on the body of a request. The returned object can be anything, but must be serializable to CBOR. @param request - internet computer request to transform
inherited
verify(Uint8List signature, Uint8List message) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited