ECKeys class

Constructors

ECKeys({Uint8List? ecChainCode, Uint8List? ecPrivateKey, Uint8List? ecPublicKey, Uint8List? ecCompressedPublicKey, String? extendedECPublicKey})

Properties

accountId → Uint8List?
no setter
ecChainCode ↔ Uint8List?
getter/setter pair
ecCompressedPublicKey ↔ Uint8List?
getter/setter pair
ecPrincipal → String?
no setter
ecPrivateKey ↔ Uint8List?
getter/setter pair
ecPublicKey ↔ Uint8List?
getter/setter pair
extendedECPublicKey ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited