Secp256k1PublicKey class

Implemented types

Constructors

Secp256k1PublicKey(BinaryBlob rawKey)

Properties

derKey DerEncodedBlob
latefinal
hashCode int
The hash code for this object.
no setterinherited
rawKey DerEncodedBlob
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDer() DerEncodedBlob
override
toRaw() DerEncodedBlob
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

DER_PREFIX DerEncodedBlob
final

Constants

RAW_KEY_LENGTH → const int