ArchiveOptions class

Constructors

ArchiveOptions({required Principal controller_id, int? max_message_size_bytes, int? node_max_memory_size_bytes})
ArchiveOptions.fromMap(Map map)
factory

Properties

controller_id ↔ Principal
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
max_message_size_bytes ↔ int?
getter/setter pair
node_max_memory_size_bytes ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

idl ↔ Record
getter/setter pair