Duration class

Constructors

Duration({required BigInt secs, required int nanos})
Duration.fromMap(Map map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nanos ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secs ↔ BigInt
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

idl ↔ Record
getter/setter pair