TransferError class

Constructors

TransferError({Map? TxTooOld, Map? BadFee, Map? TxDuplicate, bool? TxCreatedInFuture, Map? InsufficientFunds})
TransferError.fromMap(Map map)
factory

Properties

BadFee ↔ Map?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
InsufficientFunds ↔ Map?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
TxCreatedInFuture ↔ bool?
getter/setter pair
TxDuplicate ↔ Map?
getter/setter pair
TxTooOld ↔ Map?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

idl ↔ Variant
getter/setter pair