RosettaTransaction class

Contains information about a transaction.

Inheritance

Constructors

RosettaTransaction(Transaction rosettaTransaction, int blockIndex)

Properties

account1Address ↔ String?
getter/setter pair
account2Address ↔ String?
getter/setter pair
amount ↔ BigInt?
getter/setter pair
blockIndex ↔ int
Create a Transaction. @param {Any} rosettaTransaction The Rosetta Transaction object of the transaction. @param {Number} blockIndex The index of the block containing the transaction. milliseconds since the Unix Epoch.
getter/setter pair
fee ↔ BigInt?
getter/setter pair
hash ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
memo ↔ BigInt?
getter/setter pair
metadata ↔ Map<String, dynamic>?
Transactions that are related to other transactions (like a cross-shard transaction) should include the tranaction_identifier of these transactions in the metadata.
getter/setter pairinherited
operations ↔ List<Operation>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
getter/setter pair
timestamp ↔ DateTime?
getter/setter pair
transaction_identifier ↔ TransactionIdentifier
getter/setter pairinherited
type ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited