BaseAccount class abstract

Implementers

Constructors

BaseAccount()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEcIdentity() → Secp256k1KeyIdentity?
getEcKeys() → ECKeys?
getIdentity() → Ed25519KeyIdentity?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited