BaseSigner<T extends BaseAccount, R extends SignablePayload, E> class abstract

Inheritance
Implementers

Constructors

BaseSigner()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isLocked → bool?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

lock(String? passphrase) → Future<void>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(R payload, {SignType? signType = SignType.ed25519, SigningCallback? callback}) → Future<E>
inherited
toString() → String
A string representation of this object.
inherited
unlock(String passphrase, {String? keystore}) → Future<void>?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited