AccountIdentifier class

The account_identifier uniquely identifies an account within a network. All fields in the account_identifier are utilized to determine this uniqueness (including the metadata field, if populated).

Constructors

AccountIdentifier(String address, SubAccountIdentifier? sub_account, Map<String, dynamic>? metadata)
AccountIdentifier.fromMap(Map<String, dynamic> map)
factory

Properties

address ↔ String
The address may be a cryptographic public key (or some encoding of it) or a provided username.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, dynamic>?
Blockchains that utilize a username model (where the address is not a derivative of a cryptographic public key) should specify the public key(s) owned by the address in metadata.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sub_account ↔ SubAccountIdentifier?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited