ConstructionCombineRequest class

ConstructionCombineRequest is the input to the /construction/combine endpoint. It contains the unsigned transaction blob returned by /construction/payloads and all required signatures to create a network transaction.

Constructors

ConstructionCombineRequest(NetworkIdentifier network_identifier, String unsigned_transaction, List<Signature> signatures)
ConstructionCombineRequest.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
network_identifier ↔ NetworkIdentifier
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatures ↔ List<Signature>
getter/setter pair
unsigned_transaction ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited