ConstructionDeriveResponse class

ConstructionDeriveResponse is returned by the /construction/derive endpoint.

Constructors

ConstructionDeriveResponse(String? address, AccountIdentifier? account_identifier, Map<String, dynamic>? metadata)
ConstructionDeriveResponse.fromMap(Map<String, dynamic> map)
factory

Properties

account_identifier ↔ AccountIdentifier?
getter/setter pair
address ↔ String?
DEPRECATED by `account_identifier` in `v1.4.4` Address in network-specific format.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, dynamic>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited