ConstructionHashRequest class

ConstructionHashRequest is the input to the /construction/hash endpoint.

Constructors

ConstructionHashRequest(NetworkIdentifier network_identifier, String signed_transaction)
ConstructionHashRequest.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
network_identifier ↔ NetworkIdentifier
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signed_transaction ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited