NetworkIdentifier class

The network_identifier specifies which network a particular object is associated with.

Constructors

NetworkIdentifier(String blockchain, String network, SubNetworkIdentifier? sub_network_identifier)
NetworkIdentifier.fromMap(Map<String, dynamic> map)
factory

Properties

blockchain ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
network ↔ String
If a blockchain has a specific chain-id or network identifier, it should go in this field. It is up to the client to determine which network-specific identifier is mainnet or testnet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sub_network_identifier ↔ SubNetworkIdentifier?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited