NetworkOptionsResponse class

NetworkOptionsResponse contains information about the versioning of the node and the allowed operation statuses, operation types, and errors.

Constructors

NetworkOptionsResponse(Version version, Allow allow)
NetworkOptionsResponse.fromMap(Map<String, dynamic> map)
factory

Properties

allow ↔ Allow
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ Version
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited