TransactionIdentifier class

The transaction_identifier uniquely identifies a transaction in a particular network and block or in the mempool.

Constructors

TransactionIdentifier(String hash)
TransactionIdentifier.fromMap(Map<String, dynamic> map)
factory

Properties

hash ↔ String
Any transactions that are attributable only to a block (ex: a block event) should use the hash of the block as the identifier.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited