TransactionIdentifierResponse class

TransactionIdentifierResponse contains the transaction_identifier of a transaction that was submitted to either /construction/hash or /construction/submit.

Constructors

TransactionIdentifierResponse(TransactionIdentifier transaction_identifier, Map<String, dynamic>? metadata)
TransactionIdentifierResponse.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, dynamic>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transaction_identifier ↔ TransactionIdentifier
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited