Memory class

WebAssembly Memory instance. Could be shared between different instantiated modules.

Annotations

Constructors

Memory({required int initial, int? maximum})
Creates a Memory of initial pages. One page is 65536 bytes.
Memory.shared({required int initial, required int maximum})
Creates a shared Memory of initial and maximum pages. One page is 65536 bytes.

Properties

buffer → ByteBuffer
Returns a ByteBuffer backing this memory object.
no setter
hashCode → int
The hash code for this object.
no setteroverride
jsObject → _Memory
JavaScript WebAssembly.Memory object
final
lengthInBytes → int
Returns a number of bytes of ByteBuffer backing this memory object.
no setter
lengthInPages → int
Returns a number of pages backing this memory object.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

grow(int delta) → int
Increases size of allocated memory by delta pages. One page is 65536 bytes. Returns the original size before grow attempt.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override