ModuleImportDescriptor class abstract

Module imports entry.

Available extensions
Annotations
  • @JS.new()
  • @anonymous

Constructors

ModuleImportDescriptor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind → ImportExportKind

Available on ModuleImportDescriptor, provided by the ModuleImportDescriptorKind extension

Kind of imports entry.
no setter
module → String
Name of imports module, not to confuse with Module.
no setter
name → String
Name of imports entry.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited