Table class

WebAssembly Table instance. Could be shared between different instantiated modules.

Annotations

Constructors

Table.externref({required int initial, int? maximum, Object? value})
Creates a Table of initial elements of reference type.
Table.funcref({required int initial, int? maximum, Object? value})
Creates a Table of initial elements of anyfunc type.

Properties

hashCode → int
The hash code for this object.
no setteroverride
jsObject → _Table
JavaScript WebAssembly.Table object
final
length → int
Returns the size of Table.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

grow(int delta) → int
Grow the table by delta elements. Returns the previous length of the table. New memory size must not exceed maximum parameter if it was provided.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override
operator [](int index) → Object?
Returns a table element by its index.
operator []=(int index, Object? value) → void
Sets a table element by its index.